pkg

package
v0.0.0-...-689a390 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2021 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ADKey

type ADKey interface {
	DKey
	Reshare(uint16) (TDKey, error)
}

ADKey is an arithmetic distirbuted key

type ADSecret

type ADSecret interface {
	DSecret
	Reshare(uint16) (TDSecret, error)
}

ADSecret is an arithmetic distirbuted secret

func Gen

func Gen(label string, network network.Server, commType string) ADSecret

Gen generates a new distributed key with given label

type DKey

type DKey interface {
	Label() string
	RevealExp() (Elem, error)
}

DKey is a distirbuted key

type DSecret

type DSecret interface {
	Label() string
	Reveal() (*big.Int, error)
	Exp() (DKey, error)
}

DSecret is a distributed secret

type Elem

type Elem struct{}

Elem is an element in a group

type ProtocolTECDSA

type ProtocolTECDSA struct {
	// contains filtered or unexported fields
}

ProtocolTECDSA implements the tECDSA protocol

func InitTECDSA

func InitTECDSA(network network.Server) *ProtocolTECDSA

InitTECDSA constructs a new instance of tECDSA protocol

func (*ProtocolTECDSA) GenKey

func (p *ProtocolTECDSA) GenKey() error

GenKey generates a private key for signing and a secret for commitments

func (*ProtocolTECDSA) Presign

func (p *ProtocolTECDSA) Presign(t uint16)

Presign generates a new presignature

func (*ProtocolTECDSA) Sign

func (p *ProtocolTECDSA) Sign(message *big.Int) Signature

Sign generates a signature using a presignature prepared before

type Signature

type Signature struct {
	// contains filtered or unexported fields
}

Signature implements a complete signature

type TDKey

type TDKey interface {
	DKey
	Threshold() uint16
}

TDKey is a thresholded distirbuted key

type TDSecret

type TDSecret interface {
	DSecret
	Threshold() uint16
}

TDSecret is a thresholded distributed secret

Directories

Path Synopsis
Package sync in it current form works only for one round going on at a time
Package sync in it current form works only for one round going on at a time

Jump to