package
Version:
v0.0.0-...-689a390
Opens a new window with list of versions in this module.
Published: May 17, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Decoder represents encoding.Decoder for zkproofs
Encoder represents encoding.Encoder for zkproofs
type ZKproof interface {
Verify() bool
}
ZKproof represents a zero-knowledge proof that may be verified
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.