Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProtocolTECDSA ¶
type ProtocolTECDSA struct {
// contains filtered or unexported fields
}
ProtocolTECDSA implements the tECDSA protocol
func InitTECDSA ¶
func InitTECDSA(network network.Server) *ProtocolTECDSA
InitTECDSA constructs a new instance of tECDSA protocol
func (*ProtocolTECDSA) GenKey ¶
func (p *ProtocolTECDSA) GenKey() error
GenKey generates a private key for signing and a secret for commitments
func (*ProtocolTECDSA) Presign ¶
func (p *ProtocolTECDSA) Presign(t uint16)
Presign generates a new presignature
type Signature ¶
type Signature struct {
// contains filtered or unexported fields
}
Signature implements a complete signature
Directories
¶
| Path | Synopsis |
|---|---|
|
Package sync in it current form works only for one round going on at a time
|
Package sync in it current form works only for one round going on at a time |
Click to show internal directories.
Click to hide internal directories.